==> cscec5b-rmat-api-3.0.1-20221027.035229-31-sources.jar: com/ejianc/business/rmat/vo/RestituteOtherVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 其他费用
 * 
 * @author generator
 * 
 */
public class RestituteOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long restituteId; // 退赔单主键
    private String coseName; // 费用名称
    private BigDecimal otherPrice; // 单价
    private BigDecimal otherNum; // 数量
    private BigDecimal currentAmount; // 本期金额
    private String memo; // 备注
    

    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public String getCoseName() {
        return coseName;
    }

    public void setCoseName(String coseName) {
        this.coseName = coseName;
    }
    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }
    public BigDecimal getOtherNum() {
        return otherNum;
    }

    public void setOtherNum(BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    public BigDecimal getCurrentAmount() {
        return currentAmount;
    }

    public void setCurrentAmount(BigDecimal currentAmount) {
        this.currentAmount = currentAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> cscec5b-rmat-api-3.0.1-20221110.031426-84-sources.jar: com/ejianc/business/rmat/vo/RestituteOtherVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 其他费用
 * 
 * @author generator
 * 
 */
public class RestituteOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long restituteId; // 退赔单主键
    private String coseName; // 费用名称
    private BigDecimal otherPrice; // 单价
    private BigDecimal otherNum; // 数量
    private BigDecimal currentAmount; // 本期金额
    private BigDecimal currentTaxAmount; // 本期金额(含税)
    private BigDecimal taxRate; // 税率
    private String memo; // 备注
    

    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public String getCoseName() {
        return coseName;
    }

    public void setCoseName(String coseName) {
        this.coseName = coseName;
    }
    public BigDecimal getOtherPrice() {
        return otherPrice;
    }

    public void setOtherPrice(BigDecimal otherPrice) {
        this.otherPrice = otherPrice;
    }
    public BigDecimal getOtherNum() {
        return otherNum;
    }

    public void setOtherNum(BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    public BigDecimal getCurrentAmount() {
        return currentAmount;
    }

    public void setCurrentAmount(BigDecimal currentAmount) {
        this.currentAmount = currentAmount;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getCurrentTaxAmount() {
        return currentTaxAmount;
    }

    public void setCurrentTaxAmount(BigDecimal currentTaxAmount) {
        this.currentTaxAmount = currentTaxAmount;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
}
